package main

import (
	"context"
	"fmt"
	"time"

	"code.byted.org/caijing_pay/tp_golang_applet/tt_pay"
	"code.byted.org/caijing_pay/tp_golang_applet/tt_pay/config"
	"code.byted.org/caijing_pay/tp_golang_applet/tt_pay/util"
)

func main() {
	util.SetDebugMode(true)

	conf := config.Config{
		AppId:             "___________",                    // 支付方分配给业务方的ID，用于获取 签名/验签 的密钥信息
		AppSecret:         "___________",                    // 支付方密钥
		MerchantId:        "___________",                    // 支付方分配给业务方的商户编号
		TPDomain:          "https://tp-pay-test.snssdk.com", // 测试请用https://tp-pay-test.snssdk.com, 线上请用https://tp-pay.snssdk.com
		TPClientTimeoutMs: 6000,
	}
	req := tt_pay.NewTradeCreateRequest(conf)
	// 下面两个版本号，AppletVersion指的是小程序收银台版本，Version指的是财经后端下单接口版本
	// 小程序收银台版本有1.0和2.0，头条APP只在7.2.7之后支持收银台2.0版本，7.2.7之前的版本请使用1.0
	// 该参数可设置为"1.0"(返回拉起1.0收银台参数)，"2.0"(返回拉起2.0收银台参数),"2.0+"(返回一个json，包含1.0和2.0参数)
	req.AppletVersion = "2.0+"                                // 小程序收银台版本，可选1.0，2.0及2.0+
	req.Version = "2.0"                                       // 后端下单接口默认为2.0， 可更改为1.0
	req.OutOrderNo = fmt.Sprintf("%d", time.Now().Unix())     // 此处是随机生成的，使用时请填写您的商户订单号
	req.Uid = "123"                                           // 填写用户在头条的id
	req.TotalAmount = 1                                       // 填写订单金额
	req.Currency = "CNY"                                      // 填写币种，一般均为CNY
	req.Subject = "测试订单"                                      // 填写您的订单名称
	req.Body = "测试订单内容"                                       // 填写您的订单内容
	req.TradeTime = fmt.Sprintf("%d", time.Now().Unix())      // 交易时间，此处自动生成，您也可以根据需求赋值，但必须为Unix时间戳
	req.ValidTime = "36000"                                   // 填写您的订单有效时间（单位：秒）
	req.NotifyUrl = "https://google.com"                      // 填写您的异步通知地址
	req.RiskInfo = `{"ip":"127.0.0.1", "device_id":"122333"}` // 严格json字符串格式
	req.ProductCode = "pay"                                   // 固定值，不要改动
	req.TradeType = "H5"                                      // 固定值，不要改动

	// 1.0版本特有参数，当AppletVersion填"1.0"和"2.0+"时需要填写
	req.Params = `{"url":"..."}`      // 传递给支付方的支付信息，标准 json 格式字符串，不同的支付方参数格式不一样
	req.PaymentType1_0 = "ALIPAY_APP" // 1.0版本的PaymentType，目前只支持支付宝，请填写ALIPAY_APP
	req.PayChannel = "ALIPAY_NO_SIGN" // 目前只支持支付宝，请填写ALIPAY_NO_SIGN

	// 2.0版本特有参数，当AppletVersion填"2.0"和"2.0+"时需要填写
	req.PaymentType = "direct" // 2.0版本的PaymentType，固定值direct，不要改动，
	req.WxUrl = ""             // 调用微信H5支付统一下单接口返回的mweb_url字段值。service=1时(外部开发者)必传，否则无法使用微信支付
	req.WxType = ""            // service=1时(外部开发者)，且wx_url有值时，传固定值：MWEB
	req.AlipayUrl = ""         // 调用支付宝App支付的签名订单信息，详见支付宝App支付请求参数说明。service=1时(外部开发者)必传，否则无法使用支付宝支付

	ctx := context.Background()
	resp, err := tt_pay.TradeCreate(ctx, req)

	if err != nil {
		fmt.Printf("Request failed! \nRequest:\n  [%#v]\n", req)
		// 要方便获取网络错误的具体信息（code，msg，sub_code, sub_msg），需进行一次断言
		if nerr, ok := err.(*util.Error); ok {
			fmt.Printf("Error:\n  code:[%s] msg:[%s] sub_code:[%s] sub_msg:[%s]", nerr.Code, nerr.Msg, nerr.SubCode, nerr.SubMsg)
			return
		}
		fmt.Printf("Error:\n  [%s]", err)
		return
	}

	cashDeskParams, _ := resp.GetCashdeskAppletParams()
	fmt.Printf("Request succeeded! \nRequest:\n [%#v]\nResponse:\n  [%#v]\nGet CashdeskApplet Parameters:\n  [%v]\n", req, resp, cashDeskParams)
}
